# Diagonal & Scalar

::: torchlinops.linops.Diagonal
    options:
        inherited_members: false
        members:
            - __init__
            - from_weight
            - normal
            - __pow__

::: torchlinops.linops.Scalar
    options:
        inherited_members: false
        members:
            - __init__

::: torchlinops.linops.Zero
    options:
        inherited_members: false
        members:
            - __init__
